# Base class

::: polaris.benchmark.BenchmarkSpecification
    options:
        filters: ["!^_", "!md5sum", "!get_cache_path"]

---
## Subclasses

::: polaris.benchmark.SingleTaskBenchmarkSpecification

---

::: polaris.benchmark.MultiTaskBenchmarkSpecification

---